==> mp3plot-0.5.1.tar.gz: mp3plot-0.5.1/src/mp3_config.h <==
/*
 * mp3plot - Bitrate analysis tool
 *
 * Copyright (C) 2007 Toni Corvera
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

// $Id: mp3_config.h 1653 2009-04-15 01:19:47Z  $

#ifndef MP3PLOT_MP3_CONFIG_H
#define MP3PLOT_MP3_CONFIG_H

/*!
 * \file
 * This file handles the conditional includes and the optional
 * code dependant on the system configuration.
 * \remarks Files should include this file instead of config.h
 */

#include "config.h"
#if defined(_WIN32) || defined(_WIN64)
#   include "msvc/config.h"
#   include "msvc/win.h"
#endif
#include "macros.h"

// Mandatory requirements, in case configure isn't used and/or it succeeds
// when it shouldn't
#ifndef HAVE_BOOST
#   error Boost is required
#endif
#ifndef HAVE_BOOST_THREAD
#   error Boost.Thread is required
#endif
#ifndef HAVE_BOOST_PROGRAM_OPTIONS
#   error Boost.Program_Options is required
#endif

// If sysexits.h is not present define constants used through the code
#ifdef HAVE_SYSEXITS_H
#   include <sysexits.h>
#else
#   define EX_OK             0
#   define EX__BASE         64
#   define EX_USAGE         64
#   define EX_DATAERR       65
#   define EX_NOINPUT       66
#   define EX_UNAVAILABLE   69
#   define EX_SOFTWARE      70
#   define EX_IOERR         74
#endif  // HAVE_SYSEXITS_H

#include "utils/byteswap.hxx"

#endif // MP3PLOT_MP3_CONFIG_H
// vim:set ts=4 et ai:

==> mp3plot-0.6.0.tar.gz: mp3plot-0.6.0/src/mp3_config.h <==
/*
 * mp3plot - Bitrate analysis tool
 *
 * Copyright (C) 2007 Toni Corvera
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

// $Id: mp3_config.h 1343 2009-06-22 00:09:32Z toni $

#ifndef MP3PLOT_MP3_CONFIG_H
#define MP3PLOT_MP3_CONFIG_H

/*!
 * \file
 * This file handles the conditional includes and the optional
 * code dependant on the system configuration.
 * \remarks Files should include this file instead of config.h
 */

#ifdef HAVE_CONFIG_H
#   include "config.h"
#endif

#if defined(_WIN32) || defined(_WIN64)
#   include "msvc/winconfig.h"
#endif

#include "macros.h"

// Mandatory requirements, in case configure isn't used and/or it succeeds
// when it shouldn't
#ifndef HAVE_BOOST
#   error Boost is required
#endif
#ifndef HAVE_BOOST_THREAD
#   error Boost.Thread is required
#endif
#ifndef HAVE_BOOST_PROGRAM_OPTIONS
#   error Boost.Program_Options is required
#endif

// If sysexits.h is not present define constants used through the code
#ifdef HAVE_SYSEXITS_H
#   include <sysexits.h>
#else
#   define EX_OK             0
#   define EX__BASE         64
#   define EX_USAGE         64
#   define EX_DATAERR       65
#   define EX_NOINPUT       66
#   define EX_UNAVAILABLE   69
#   define EX_SOFTWARE      70
#   define EX_IOERR         74
#endif  // HAVE_SYSEXITS_H

#include "utils/byteswap.hxx"

#endif // MP3PLOT_MP3_CONFIG_H
// vim:set ts=4 et ai:
